import warnings
from django.conf import settings

warnings.filterwarnings("ignore", category=DeprecationWarning)

import os
import sys


def pytest_collection_modifyitems(items):
    pass


def pytest_configure(config):
    here = os.path.dirname(__file__)
    sys.path.insert(0, here)

    if not settings.configured:
        os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.settings'




def runtests(args=None):
    import pytest

    if not args:
        args = []

    if not any(a for a in args[1:] if not a.startswith('-')):
        args.append('concurrency')

    sys.exit(pytest.main(args))


if __name__ == '__main__':
    runtests(sys.argv)



# from modeltranslation.translator import translator, TranslationOptions
# from geo.models import Country
#
#
# class CountryTranslationOptions(TranslationOptions):
#     fields = ('name',)
#
#
# translator.register(Country, CountryTranslationOptions)



# -*- coding: utf-8 -*-
'''
Created on May 7, 2010

@author: sax
'''
import functools
import warnings
from datetime import datetime
from bitfield.models import BitField
from timezone_field import TimeZoneField
from uuidfield import UUIDField
from django.core.exceptions import ValidationError, ObjectDoesNotExist
from django.core.validators import MinLengthValidator, RegexValidator
from django.db import models
from django.db.models.manager import Manager
from django.utils.translation import ugettext_lazy as _
import logging
from mptt.managers import TreeManager
from mptt.models import MPTTModel, TreeForeignKey
from separatedvaluesfield.models import SeparatedValuesField

logger = logging.getLogger("geo")


class CurrencyManager(Manager):
    use_for_related_fields = True

    def get_by_natural_key(self, uuid):
        return self.get(uuid=uuid)


class Currency(models.Model):
    uuid = UUIDField(auto=True, blank=False, version=1, help_text=_('unique id'), default="")
    iso_code = models.CharField(max_length=5, db_index=True, unique=True, help_text="ISO 4217 code")
    numeric_code = models.CharField(max_length=5, unique=True, help_text="ISO 4217 code")
    decimals = models.IntegerField(default=0)
    name = models.CharField(max_length=100)
    symbol = models.CharField(max_length=5, blank=True, null=True)
    objects = CurrencyManager()

    class Meta:
        app_label = 'geo'
        ordering = ['iso_code', ]
        verbose_name_plural = 'Currencies'

    def __unicode__(self):
        return unicode("%s (%s)" % (self.iso_code, self.name))

    def natural_key(self):
        return self.uuid.hex,


CONTINENTS = (
    ('AF', _('Africa')),
    ('AN', _('Antartica')),
    ('AS', _('Asia')),
    ('EU', _('Europe')),
    ('NA', _('North America')),
    ('OC', _('Oceania')),
    ('SA', _('South America')),
)


class CountryManager(Manager):
    use_for_related_fields = True

    def valid(self):
        return self.get_query_set().filter(expired__isnull=True)

    def _by_continent(self, continent):
        return self.valid().filter(continent=continent)

    def asia(self):
        return self._by_continent('AS')

    def europa(self):
        return self._by_continent('EU')

    def north_america(self):
        return self._by_continent('NA')

    def south_america(self):
        return self._by_continent('SA')

    def oceania(self):
        return self._by_continent('OC')

    def antartica(self):
        return self._by_continent('AN')

    def get_by_natural_key(self, uuid):
        return self.get(uuid=uuid)


class UNRegion(models.Model):
    code = models.CharField(max_length=5, unique=True, blank=False, null=False, db_index=True)

    name = models.CharField(max_length=100)
    last_update = models.DateTimeField(auto_now=True)

    class Meta:
        app_label = 'geo'
        verbose_name_plural = _('UN Regions')
        ordering = ['name']

    def __unicode__(self):
        return self.name


class Country(models.Model):
    """ Model for the country of origin.
    """
    iso_code = models.CharField(max_length=2, unique=True, blank=False, null=False, db_index=True,
                                help_text='ISO 3166-1 alpha 2', validators=[MinLengthValidator(2)])
    iso_code3 = models.CharField(max_length=3, unique=True, blank=False, null=False, db_index=True,
                                 help_text='ISO 3166-1 alpha 3', validators=[MinLengthValidator(3)])
    iso_num = models.CharField(max_length=3, unique=True, blank=False, null=False,
                               help_text='ISO 3166-1 numeric', validators=[RegexValidator('\d\d\d')])
    uuid = UUIDField(auto=True, blank=False, version=1, help_text=_('unique id'), default="")

    undp = models.CharField(max_length=3, unique=True, blank=True, null=True,
                            help_text='UNDP code', validators=[MinLengthValidator(3)])

    nato3 = models.CharField(max_length=3, unique=True, blank=True, null=True,
                             help_text='NATO3 code', validators=[MinLengthValidator(3)])

    fips = models.CharField(max_length=255, blank=True, null=True,
                            help_text='fips code')

    itu = models.CharField(max_length=255, blank=True, null=True,
                           help_text='ITU code')

    icao = models.CharField(max_length=255, blank=True, null=True, help_text='ICAO code')

    name = models.CharField(max_length=100, db_index=True)

    fullname = models.CharField(max_length=100, db_index=True)

    region = models.ForeignKey(UNRegion, blank=True, null=True, default=None)
    continent = models.CharField(choices=CONTINENTS, max_length=2)
    currency = models.ForeignKey(Currency, blank=True, null=True)

    tld = models.CharField(help_text='Internet tld', max_length=5, blank=True, null=True)
    phone_prefix = models.CharField(help_text='Phone prefix number', max_length=20, blank=True, null=True)

    timezone = TimeZoneField(blank=True, null=True, default=None)
    expired = models.DateField(blank=True, null=True, default=None)

    lat = models.DecimalField("Latitude", max_digits=18, decimal_places=12, blank=True, null=True)
    lng = models.DecimalField("Longitude", max_digits=18, decimal_places=12, blank=True, null=True)

    last_update = models.DateTimeField(auto_now=True)

    fullname.alphabetic_filter = True
    objects = CountryManager()


    class Meta:
        app_label = 'geo'
        verbose_name_plural = _('Countries')
        ordering = ['name']

    def __unicode__(self):
        return u"%s (%s)" % (self.fullname, self.iso_code)

    def clean(self):
        super(Country, self).clean()
        self.iso_code = self.iso_code.upper()
        self.iso_code3 = self.iso_code3.upper()

    def natural_key(self):
        return (self.uuid.hex, )

    def __contains__(self, item):
        if hasattr(item, 'country'):
            return item.country.iso_code == self.iso_code

    def sub(self, type):
        return self.areas.filter(type__name=type)


class AdministrativeAreaTypeManager(TreeManager):
    use_for_related_fields = True

    def get_by_natural_key(self, uuid):
        return self.get(uuid=uuid)


class AdministrativeAreaType(MPTTModel):
    uuid = UUIDField(auto=True, blank=False, version=1, help_text=_('unique id'), default="")
    name = models.CharField(_('Name'), max_length=100, db_index=True)
    country = models.ForeignKey(Country)
    parent = TreeForeignKey('self', null=True, blank=True, related_name='children')

    objects = AdministrativeAreaTypeManager()

    class Meta:
        verbose_name = _("Administrative Area Type")
        verbose_name_plural = _("Administrative Area Types")
        app_label = 'geo'
        ordering = ['name']
        order_with_respect_to = 'country'
        unique_together = (('country', 'name'),)

    def __unicode__(self):
        return unicode(self.name)

    def __contains__(self, item):
        if isinstance(item, AdministrativeAreaType) and item.is_child_node():
            return item.is_descendant_of(self)

    def natural_key(self):
        return (self.uuid.hex, )

    natural_key.dependencies = ['geo.country']

    def clean(self):
        if self.parent == self:
            raise ValidationError(_('`%s` cannot contains same type') % self.parent)
        super(AdministrativeAreaType, self).clean()

    def get_or_create(self, **kwargs):
        return AdministrativeArea.objects.get_or_create(country=self.country, type=self, **kwargs)


class AdministrativeAreaManager(TreeManager):
    use_for_related_fields = True

    def get_by_natural_key(self, uuid):
        return self.get(uuid=uuid)


class AdministrativeArea(MPTTModel):
    """ Administrative areas that can contains other AdministrativeArea and/or Location.
    """

    uuid = UUIDField(auto=True, blank=False, version=1, help_text=_('unique id'), default="")
    name = models.CharField(_('Name'), max_length=255, db_index=True)
    code = models.CharField(_('Code'), max_length=10, blank=True, null=True, db_index=True, help_text='ISO 3166-2 code')
    parent = TreeForeignKey('self', null=True, blank=True, default=None, related_name='areas')
    country = models.ForeignKey(Country, related_name='areas')
    type = models.ForeignKey(AdministrativeAreaType)
    objects = AdministrativeAreaManager()

    class Meta:
        verbose_name = _("Administrative Area")
        verbose_name_plural = _("Administrative Areas")
        unique_together = (('name', 'country', 'type'),)
        app_label = 'geo'
        ordering = ['name']
        order_with_respect_to = 'country'

    def __unicode__(self):
        return unicode(self.name)

    def __repr__(self):
        return "<%s: %s>" % (self.type.name, self.name)

    def natural_key(self):
        return (self.uuid.hex, )

    natural_key.dependencies = ['geo.administrativeareatype', 'geo.country']

    def clean(self):
        if self.parent == self:
            raise ValidationError(_('`%s` cannot contains self') % self)
        if self.parent and self.parent.type == self.type:
            raise ValidationError(_('`%s` cannot contains same type') % self.parent.type)
        if (self.pk and self.parent) and self.parent in self:
            raise ValidationError(_('`%s` cannot contains `%s`') % (self, self.parent))
        super(AdministrativeArea, self).clean()

    def save(self, *args, **kwargs):
        if not self.country_id:
            self.country = self.parent.country
        self.clean()
        super(AdministrativeArea, self).save(*args, **kwargs)

    def __contains__(self, item):
        if isinstance(item, AdministrativeArea) and item.is_child_node():
            return item.is_descendant_of(self)
        elif isinstance(item, Location) and item.area:
            return item.area.is_descendant_of(self)


class LocationTypeManager(models.Manager):
    use_for_related_fields = True

    def get_by_natural_key(self, uuid):
        return self.get(uuid=uuid)


class LocationType(models.Model):
    """Type of the location (city, village, place, locality, neighbourhood, etc.)
    This is not intended to contain anything inside it.
    """
    uuid = UUIDField(auto=True, blank=False, version=1, help_text=_('unique id'), default="")
    description = models.CharField(unique=True, max_length=100)
    objects = LocationTypeManager()

    class Meta:
        verbose_name_plural = _('Location Types')
        verbose_name = _('Location Type')
        app_label = 'geo'

    def natural_key(self):
        return (self.uuid.hex, )


class LocationManager(models.Manager):
    use_for_related_fields = True

    def get_or_none(self, *args, **kwargs):
        try:
            return self.get(*args, **kwargs)
        except ObjectDoesNotExist:
            return None

    def get_by_natural_key(self, uuid):
        return self.get(uuid=uuid)


class Location(models.Model):
    """Administrative location (city, place everything with a name and Lat/Lng that
    is not intended to contain anything; use Areas for that).
    """
    NONE = 0
    COUNTRY = 10
    EXACT = 20

    ACCURACY = (
        (NONE, _('None')),
        (COUNTRY, _('Country')),
        (EXACT, _('Exact')))

    country = models.ForeignKey(Country, db_index=True)
    area = models.ForeignKey(AdministrativeArea, db_index=True, blank=True, null=True)
    type = models.ForeignKey(LocationType, blank=True, null=True)

    is_capital = models.BooleanField(default=False, help_text="True if is the capital of `country`")
    is_administrative = models.BooleanField(default=False, help_text="True if is administrative for `area`")
    uuid = UUIDField(auto=True, blank=False, version=1, help_text=_('unique id'), default="")

    name = models.CharField(_('Name'), max_length=255, db_index=True)
    loccode = models.CharField(_('UN LOCODE'), max_length=255, db_index=True, blank=True, null=True)
    iata = models.CharField(_('IATA code (if exists)'), max_length=255, db_index=True, blank=True, null=True)

    description = models.CharField(max_length=100, blank=True, null=True)
    lat = models.DecimalField(max_digits=18, decimal_places=12, blank=True, null=True)
    lng = models.DecimalField(max_digits=18, decimal_places=12, blank=True, null=True)
    acc = models.IntegerField(choices=ACCURACY, default=NONE, blank=True, null=True,
                              help_text="Define the level of accuracy of lat/lng infos")

    flags = BitField(flags=({0: 'unknown',
                             1: 'port',
                             2: 'rail_terminal',
                             3: 'road_terminal',
                             4: 'airport',
                             5: 'postal_exchange',
                             6: 'reserved',
                             7: 'reserved'}),
                     default=0)

    status = models.CharField(max_length=2,
                              blank=True, null=True,
                              choices=(
                                  ('AA', 'Approved by competent national government agency'),
                                  ('AC', 'Approved by Customs Authority'),
                                  ('AF', 'Approved by national facilitation body'),
                                  ('AI', 'Code adopted by international organisation (IATA or ECLAC)'),
                                  ('RL', 'Recognised location - Existence and representation of location name '
                                         'confirmed by check against nominated gazetteer or other reference work'),
                                  ('RN', 'Request from credible national sources for locations in their own country'),
                                  ('RQ', 'Request under consideration'),
                                  ('RR', 'Request rejected'),
                                  ('QQ', 'Original entry not verified since date indicated'),
                                  ('XX', 'Entry that will be removed from the next issue of UN/LOCODE'),
                              ))
    objects = LocationManager()


    class Meta:
        verbose_name_plural = _('Locations')
        verbose_name = _('Location')
        app_label = 'geo'
        ordering = ('name', 'country', )
        order_with_respect_to = 'country'
        unique_together = (('area', 'name'), )


    def __unicode__(self):
        return unicode(self.name)


    def natural_key(self):
        return (self.uuid.hex, )


    natural_key.dependencies = ['geo.administrativearea', 'geo.country', 'geo.locationtype']


    def clean(self):
        if self.area and self.area.country != self.country:
            raise ValidationError('Selected area not in selected country')
        super(Location, self).clean()



# -*- coding: utf-8 -*-
from django.apps import AppConfig as AC
from timezone_field import TimeZoneField


class AppConfig(AC):

    name = 'geo'
    label = 'geo'
    verbose_name = 'Geo'

    def ready(self):
        from bitfield.models import BitField

        def deconstruct_factory(model, **field_kwargs):
            def _dd(self):
                name, path, args, kwargs = super(model, self).deconstruct()
                kwargs.update(field_kwargs)
                return name, path, args, kwargs
            return _dd

        BitField.deconstruct = deconstruct_factory(BitField, flags=[])
        TimeZoneField.deconstruct = deconstruct_factory(TimeZoneField, choices=None)



# -*- coding: utf-8 -*-
import pytest
from geo.forms import administrativeareaform_factory_for_country
from geo.models import AdministrativeArea
from .fixtures import hierachy


@pytest.mark.django_db
def test_administrativeareaform_factory(hierachy):
    italy, regione, provincia, comune = hierachy
    Form = administrativeareaform_factory_for_country(italy)
    instance = AdministrativeArea()
    form = Form({'name': 'Lazio',
                 'type': regione.pk,
                 'country': italy.pk},
                instance=instance)
    form.full_clean()
    assert form.is_valid()



import pytest
import sys
from geo.utils import load_currency, load_country

#
# @pytest.mark.django_db
# def test_load_currency():
#     load_currency()
#
#
# @pytest.mark.django_db
# def test_load_country():
#     load_country()



# -*- coding: utf-8 -*-
import string
from functools import wraps
from random import choice

_sequence_counters = {}
_cache_unique = {}

def infinite():
    """
        auto inc generator
    """
    i = 0
    while 1:
        yield i
        i += 1



def text(length, choices=string.ascii_letters):
    """ returns a random (fixed length) string

    :param length: string length
    :param choices: string containing all the chars can be used to build the string

    .. seealso::
       :py:func:`rtext`
    """
    return ''.join(choice(choices) for x in range(length))


def sequence(prefix, cache=None):
    """
    generator that returns an unique string

    :param prefix: prefix of string
    :param cache: cache used to store the last used number

    >>> next(sequence('abc'))
    'abc-0'
    >>> next(sequence('abc'))
    'abc-1'
    """
    if cache is None:
        cache = _sequence_counters
    if cache == -1:
        cache = {}

    if prefix not in cache:
        cache[prefix] = infinite()

    yield "{0}-{1}".format(prefix, next(cache[prefix]))



def unique(func, num_args=0, max_attempts=100, cache=None):
    """
    wraps a function so that produce unique results

    :param func:
    :param num_args:

    >>> import random
    >>> choices = [1,2]
    >>> a = unique(random.choice, 1)
    >>> a,b = a(choices), a(choices)
    >>> a == b
    False
    """
    if cache is None:
        cache = _cache_unique

    @wraps(func)
    def wrapper(*args):
        key = "%s_%s" % (str(func.__name__), str(args[:num_args]))
        attempt = 0
        while attempt < max_attempts:
            attempt += 1
            drawn = cache.get(key, [])
            result = func(*args)
            if result not in drawn:
                drawn.append(result)
                cache[key] = drawn
                return result

        raise MaxAttemptException()

    return wrapper



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('geo', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='location',
            name='iata',
            field=models.CharField(verbose_name='IATA code (if exists)', blank=True, max_length=255, db_index=True, null=True),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Location._order'
        db.add_column('geo_location', '_order',
                      self.gf('django.db.models.fields.IntegerField')(default=0),
                      keep_default=False)

        # Adding unique constraint on 'Location', fields ['area', 'name']
        db.create_unique('geo_location', ['area_id', 'name'])


    def backwards(self, orm):
        # Removing unique constraint on 'Location', fields ['area', 'name']
        db.delete_unique('geo_location', ['area_id', 'name'])

        # Deleting field 'Location._order'
        db.delete_column('geo_location', '_order')


    models = {
        'geo.administrativearea': {
            'Meta': {'object_name': 'AdministrativeArea', 'ordering': "('_order',)", 'unique_together': "(('name', 'country', 'type'),)"},
            '_order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'code': ('django.db.models.fields.CharField', [], {'null': 'True', 'db_index': 'True', 'max_length': '10', 'blank': 'True'}),
            'country': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['geo.Country']", 'related_name': "'areas'"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            u'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'}),
            'parent': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'null': 'True', 'to': "orm['geo.AdministrativeArea']", 'default': 'None', 'related_name': "'areas'"}),
            u'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['geo.AdministrativeAreaType']"}),
            'uuid': ('uuidfield.fields.UUIDField', [], {'blank': 'True', 'max_length': '32', 'default': "''", 'unique': 'True'})
        },
        'geo.administrativeareatype': {
            'Meta': {'object_name': 'AdministrativeAreaType', 'ordering': "('_order',)", 'unique_together': "(('country', 'name'),)"},
            '_order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'country': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['geo.Country']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            u'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'db_index': 'True'}),
            'parent': ('mptt.fields.TreeForeignKey', [], {'blank': 'True', 'null': 'True', 'to': "orm['geo.AdministrativeAreaType']", 'related_name': "'children'"}),
            u'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            u'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'uuid': ('uuidfield.fields.UUIDField', [], {'blank': 'True', 'max_length': '32', 'default': "''", 'unique': 'True'})
        },
        'geo.country': {
            'Meta': {'object_name': 'Country', 'ordering': "['name']"},
            'continent': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'currency': ('django.db.models.fields.related.ForeignKey', [], {'null': 'True', 'to': "orm['geo.Currency']", 'blank': 'True'}),
            'expired': ('django.db.models.fields.DateField', [], {'null': 'True', 'default': 'None', 'blank': 'True'}),
            'fips': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '255', 'blank': 'True'}),
            'fullname': ('django.db.models.fields.CharField', [], {'max_length': '100', 'db_index': 'True'}),
            'icao': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '255', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'iso_code': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '2', 'unique': 'True'}),
            'iso_code3': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '3', 'unique': 'True'}),
            'iso_num': ('django.db.models.fields.CharField', [], {'max_length': '3', 'unique': 'True'}),
            'itu': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '255', 'blank': 'True'}),
            'last_update': ('django.db.models.fields.DateTimeField', [], {'blank': 'True', 'default': 'datetime.datetime.now', 'auto_now': 'True'}),
            'lat': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '18', 'decimal_places': '12', 'blank': 'True'}),
            'lng': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '18', 'decimal_places': '12', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'db_index': 'True'}),
            'nato3': ('django.db.models.fields.CharField', [], {'null': 'True', 'blank': 'True', 'max_length': '3', 'unique': 'True'}),
            'phone_prefix': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '20', 'blank': 'True'}),
            'region': ('django.db.models.fields.related.ForeignKey', [], {'null': 'True', 'to': "orm['geo.UNRegion']", 'default': 'None', 'blank': 'True'}),
            'timezone': ('timezone_field.fields.TimeZoneField', [], {'null': 'True', 'default': 'None', 'blank': 'True'}),
            'tld': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '5', 'blank': 'True'}),
            'undp': ('django.db.models.fields.CharField', [], {'null': 'True', 'blank': 'True', 'max_length': '3', 'unique': 'True'}),
            'uuid': ('uuidfield.fields.UUIDField', [], {'blank': 'True', 'max_length': '32', 'default': "''", 'unique': 'True'})
        },
        'geo.currency': {
            'Meta': {'object_name': 'Currency', 'ordering': "['iso_code']"},
            'decimals': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'iso_code': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '5', 'unique': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'numeric_code': ('django.db.models.fields.CharField', [], {'max_length': '5', 'unique': 'True'}),
            'symbol': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '5', 'blank': 'True'}),
            'uuid': ('uuidfield.fields.UUIDField', [], {'blank': 'True', 'max_length': '32', 'default': "''", 'unique': 'True'})
        },
        'geo.location': {
            'Meta': {'object_name': 'Location', 'ordering': "('_order',)", 'unique_together': "(('area', 'name'),)"},
            '_order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'acc': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'default': '0', 'blank': 'True'}),
            'area': ('django.db.models.fields.related.ForeignKey', [], {'null': 'True', 'to': "orm['geo.AdministrativeArea']", 'blank': 'True'}),
            'country': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['geo.Country']"}),
            'description': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '100', 'blank': 'True'}),
            'flags': ('django.db.models.fields.BigIntegerField', [], {'default': '0'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_administrative': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_capital': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'lat': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '18', 'decimal_places': '12', 'blank': 'True'}),
            'lng': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '18', 'decimal_places': '12', 'blank': 'True'}),
            'loccode': ('django.db.models.fields.CharField', [], {'null': 'True', 'db_index': 'True', 'max_length': '255', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'}),
            'status': ('django.db.models.fields.CharField', [], {'null': 'True', 'max_length': '2', 'blank': 'True'}),
            'type': ('django.db.models.fields.related.ForeignKey', [], {'null': 'True', 'to': "orm['geo.LocationType']", 'blank': 'True'}),
            'uuid': ('uuidfield.fields.UUIDField', [], {'blank': 'True', 'max_length': '32', 'default': "''", 'unique': 'True'})
        },
        'geo.locationtype': {
            'Meta': {'object_name': 'LocationType'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '100', 'unique': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'uuid': ('uuidfield.fields.UUIDField', [], {'blank': 'True', 'max_length': '32', 'default': "''", 'unique': 'True'})
        },
        'geo.unregion': {
            'Meta': {'object_name': 'UNRegion', 'ordering': "['name']"},
            'code': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '5', 'unique': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_update': ('django.db.models.fields.DateTimeField', [], {'blank': 'True', 'auto_now': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['geo']


from django.contrib import admin
from django.conf.urls import patterns, include
from django.conf import settings
from django.conf.urls.static import static

admin.autodiscover()

urlpatterns = patterns('',
                    (r'', include(admin.site.urls)),

) + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import bitfield.models
import django.core.validators
import mptt.fields
import uuidfield.fields
import timezone_field.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AdministrativeArea',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('uuid', uuidfield.fields.UUIDField(help_text='unique id', unique=True, editable=False, blank=True, default=b'', max_length=32)),
                ('name', models.CharField(max_length=255, verbose_name='Name', db_index=True)),
                ('code', models.CharField(help_text=b'ISO 3166-2 code', verbose_name='Code', db_index=True, blank=True, null=True, max_length=10)),
                ('lft', models.PositiveIntegerField(editable=False, db_index=True)),
                ('rght', models.PositiveIntegerField(editable=False, db_index=True)),
                ('tree_id', models.PositiveIntegerField(editable=False, db_index=True)),
                ('level', models.PositiveIntegerField(editable=False, db_index=True)),
                ('parent', mptt.fields.TreeForeignKey(to='geo.AdministrativeArea', blank=True, default=None, null=True)),
            ],
            options={
                'verbose_name_plural': 'Administrative Areas',
                'ordering': [b'name'],
                'verbose_name': 'Administrative Area',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AdministrativeAreaType',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('uuid', uuidfield.fields.UUIDField(help_text='unique id', unique=True, editable=False, blank=True, default=b'', max_length=32)),
                ('name', models.CharField(max_length=100, verbose_name='Name', db_index=True)),
                ('lft', models.PositiveIntegerField(editable=False, db_index=True)),
                ('rght', models.PositiveIntegerField(editable=False, db_index=True)),
                ('tree_id', models.PositiveIntegerField(editable=False, db_index=True)),
                ('level', models.PositiveIntegerField(editable=False, db_index=True)),
                ('parent', mptt.fields.TreeForeignKey(to='geo.AdministrativeAreaType', blank=True, null=True)),
            ],
            options={
                'verbose_name_plural': 'Administrative Area Types',
                'ordering': [b'name'],
                'verbose_name': 'Administrative Area Type',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='administrativearea',
            name='type',
            field=models.ForeignKey(to='geo.AdministrativeAreaType'),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('iso_code', models.CharField(max_length=2, db_index=True, unique=True, help_text=b'ISO 3166-1 alpha 2', validators=[django.core.validators.MinLengthValidator(2)])),
                ('iso_code3', models.CharField(max_length=3, db_index=True, unique=True, help_text=b'ISO 3166-1 alpha 3', validators=[django.core.validators.MinLengthValidator(3)])),
                ('iso_num', models.CharField(max_length=3, unique=True, help_text=b'ISO 3166-1 numeric', validators=[django.core.validators.RegexValidator(b'\\d\\d\\d')])),
                ('uuid', uuidfield.fields.UUIDField(help_text='unique id', unique=True, editable=False, blank=True, default=b'', max_length=32)),
                ('undp', models.CharField(validators=[django.core.validators.MinLengthValidator(3)], help_text=b'UNDP code', unique=True, blank=True, max_length=3, null=True)),
                ('nato3', models.CharField(validators=[django.core.validators.MinLengthValidator(3)], help_text=b'NATO3 code', unique=True, blank=True, max_length=3, null=True)),
                ('fips', models.CharField(blank=True, max_length=255, help_text=b'fips code', null=True)),
                ('itu', models.CharField(blank=True, max_length=255, help_text=b'ITU code', null=True)),
                ('icao', models.CharField(blank=True, max_length=255, help_text=b'ICAO code', null=True)),
                ('name', models.CharField(max_length=100, db_index=True)),
                ('fullname', models.CharField(max_length=100, db_index=True)),
                ('continent', models.CharField(choices=[(b'AF', 'Africa'), (b'AN', 'Antartica'), (b'AS', 'Asia'), (b'EU', 'Europe'), (b'NA', 'North America'), (b'OC', 'Oceania'), (b'SA', 'South America')], max_length=2)),
                ('tld', models.CharField(blank=True, max_length=5, help_text=b'Internet tld', null=True)),
                ('phone_prefix', models.CharField(blank=True, max_length=20, help_text=b'Phone prefix number', null=True)),
                ('timezone', timezone_field.fields.TimeZoneField(blank=True, default=None, max_length=63, choices=None, null=True)),
                ('expired', models.DateField(blank=True, default=None, null=True)),
                ('lat', models.DecimalField(blank=True, decimal_places=12, verbose_name=b'Latitude', max_digits=18, null=True)),
                ('lng', models.DecimalField(blank=True, decimal_places=12, verbose_name=b'Longitude', max_digits=18, null=True)),
                ('last_update', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': [b'name'],
                'verbose_name_plural': 'Countries',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='administrativeareatype',
            name='country',
            field=models.ForeignKey(to='geo.Country'),
            preserve_default=True,
        ),
        migrations.AlterOrderWithRespectTo(
            name='administrativeareatype',
            order_with_respect_to=b'country',
        ),
        migrations.AlterUniqueTogether(
            name='administrativeareatype',
            unique_together=set([(b'country', b'name')]),
        ),
        migrations.AddField(
            model_name='administrativearea',
            name='country',
            field=models.ForeignKey(to='geo.Country'),
            preserve_default=True,
        ),
        migrations.AlterOrderWithRespectTo(
            name='administrativearea',
            order_with_respect_to=b'country',
        ),
        migrations.AlterUniqueTogether(
            name='administrativearea',
            unique_together=set([(b'name', b'country', b'type')]),
        ),
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('uuid', uuidfield.fields.UUIDField(help_text='unique id', unique=True, editable=False, blank=True, default=b'', max_length=32)),
                ('iso_code', models.CharField(max_length=5, unique=True, help_text=b'ISO 4217 code', db_index=True)),
                ('numeric_code', models.CharField(unique=True, help_text=b'ISO 4217 code', max_length=5)),
                ('decimals', models.IntegerField(default=0)),
                ('name', models.CharField(max_length=100)),
                ('symbol', models.CharField(blank=True, max_length=5, null=True)),
            ],
            options={
                'ordering': [b'iso_code'],
                'verbose_name_plural': b'Currencies',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='country',
            name='currency',
            field=models.ForeignKey(to='geo.Currency', blank=True, null=True),
            preserve_default=True,
        ),
        migrations.CreateModel(
            name='Location',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('is_capital', models.BooleanField(default=False, help_text=b'True if is the capital of `country`')),
                ('is_administrative', models.BooleanField(default=False, help_text=b'True if is administrative for `area`')),
                ('uuid', uuidfield.fields.UUIDField(help_text='unique id', unique=True, editable=False, blank=True, default=b'', max_length=32)),
                ('name', models.CharField(max_length=255, verbose_name='Name', db_index=True)),
                ('loccode', models.CharField(blank=True, max_length=255, null=True, verbose_name='UN LOCODE', db_index=True)),
                ('description', models.CharField(blank=True, max_length=100, null=True)),
                ('lat', models.DecimalField(blank=True, decimal_places=12, max_digits=18, null=True)),
                ('lng', models.DecimalField(blank=True, decimal_places=12, max_digits=18, null=True)),
                ('acc', models.IntegerField(blank=True, default=0, choices=[(0, 'None'), (10, 'Country'), (20, 'Exact')], help_text=b'Define the level of accuracy of lat/lng infos', null=True)),
                ('flags', bitfield.models.BitField(default=0, flags=[])),
                ('status', models.CharField(blank=True, max_length=2, choices=[(b'AA', b'Approved by competent national government agency'), (b'AC', b'Approved by Customs Authority'), (b'AF', b'Approved by national facilitation body'), (b'AI', b'Code adopted by international organisation (IATA or ECLAC)'), (b'RL', b'Recognised location - Existence and representation of location name confirmed by check against nominated gazetteer or other reference work'), (b'RN', b'Request from credible national sources for locations in their own country'), (b'RQ', b'Request under consideration'), (b'RR', b'Request rejected'), (b'QQ', b'Original entry not verified since date indicated'), (b'XX', b'Entry that will be removed from the next issue of UN/LOCODE')], null=True)),
                ('area', models.ForeignKey(to='geo.AdministrativeArea', blank=True, null=True)),
                ('country', models.ForeignKey(to='geo.Country')),
            ],
            options={
                'verbose_name_plural': 'Locations',
                'ordering': (b'name', b'country'),
                'verbose_name': 'Location',
            },
            bases=(models.Model,),
        ),
        migrations.AlterOrderWithRespectTo(
            name='location',
            order_with_respect_to=b'country',
        ),
        migrations.CreateModel(
            name='LocationType',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('uuid', uuidfield.fields.UUIDField(help_text='unique id', unique=True, editable=False, blank=True, default=b'', max_length=32)),
                ('description', models.CharField(unique=True, max_length=100)),
            ],
            options={
                'verbose_name_plural': 'Location Types',
                'verbose_name': 'Location Type',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='location',
            name='type',
            field=models.ForeignKey(to='geo.LocationType', blank=True, null=True),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='location',
            unique_together=set([(b'area', b'name')]),
        ),
        migrations.CreateModel(
            name='UNRegion',
            fields=[
                ('id', models.AutoField(auto_created=True, verbose_name='ID', serialize=False, primary_key=True)),
                ('code', models.CharField(max_length=5, unique=True, db_index=True)),
                ('name', models.CharField(max_length=100)),
                ('last_update', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': [b'name'],
                'verbose_name_plural': 'UN Regions',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='country',
            name='region',
            field=models.ForeignKey(to='geo.UNRegion', blank=True, default=None, null=True),
            preserve_default=True,
        ),
    ]
